esgf-playground-utils
---------------------

Common models, configuration and functionality for the ESGF-Playground.

Please read this `documentation <https://esgf.github.io/esgf-playground-utils/>`__
in GitHub.

